@@ -1,4 +1,4 @@
-#  Copyright 2020-2022 Robert Bosch GmbH
+#  Copyright 2020-2023 Robert Bosch GmbH
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -73,9 +73,6 @@ Base class for all connection classes.
    _start_dlt_lock = threading.RLock()
 
    _traceq_handle = 0
-   _traceq_obj = {}
-   _traceq_lock = threading.Lock()
-
    supported_devices = []
 
    # # for continuous processing
@@ -93,16 +90,16 @@ Base class for all connection classes.
    def __new__(cls, *args, **kwargs):
       """
 Override creating instance method to check for conditions.
-      
+
 **Arguments:**
 
-* ``args``    
+* ``args``
 
   / *Condition*: require / *Type*: tuple /
 
   Non-Keyword Arguments.
 
-* ``kwargs``   
+* ``kwargs``
 
   / *Condition*: require / *Type*: dict /
 
@@ -111,7 +108,7 @@ Override creating instance method to check for conditions.
 **Returns:**
 
   / *Type*: ConnectionBase /
-  
+
   ConnectionBase instance if passing the conditions.\
   None if failing the conditions.
       """
@@ -128,10 +125,10 @@ Check if current platform is supported.
 **Returns:**
 
   / *Type*: bool /
-  
-  True if platform is supported. 
-  
-  False if platform is not supported.
+
+  ``True`` if platform is supported.
+
+  ``False`` if platform is not supported.
       """
       return _platform in cls._SUPPORTED_PLATFORM_LIST
 
@@ -139,17 +136,17 @@ Check if current platform is supported.
    def is_precondition_pass(cls):
       """
 Check for precondition.
-	  
+
 **Returns:**
 
   / *Type*: bool /
 
-  True if passing the precondition.
+  ``True`` if passing the precondition.
 
-  False if failing the precondition.
+  ``False`` if failing the precondition.
       """
       return cls._is_precondition_valid
-      
+
    @classmethod
    def get_connection_type(cls):
       """
@@ -166,11 +163,11 @@ Get the connection type.
    def error_instruction(self):
       """
 Get the error instruction.
-	  
+
 **Returns:**
 
   / *Type*: str /
-    
+
   Error instruction string.
       """
       return self._ERROR_INSTRUCTION
@@ -180,49 +177,50 @@ Get the error instruction.
    @abc.abstractmethod
    def quit(self, is_disconnect_all=True):
       """
->> This method MUST be overridden in derived class << 
+>> This method MUST be overridden in derived class <<
 
 Abstract method for quiting the connection.
-      
+
 **Arguments:**
 
-* ``is_disconnect_all``    
+* ``is_disconnect_all``
 
   / *Condition*: optional / *Type*: bool /
-  
+
   Determine if it's necessary to disconnect all connections.
 
 **Returns:**
 
 (*no returns*)
       """
-      self._logger.removeHandler(self._logger_handler)
+      if self._logger:
+         self._logger.removeHandler(self._logger_handler)
 
    @abc.abstractmethod
    def connect(self, device, files=None, test_connection=False):
       """
->> This method MUST be overridden in derived class << 
+>> This method MUST be overridden in derived class <<
 
 Abstract method for quiting the connection.
-      
+
 **Arguments:**
 
-* ``device``    
+* ``device``
 
   / *Condition*: required / *Type*: str /
-  
+
   Device name.
 
-* ``files``    
+* ``files``
 
   / *Condition*: optional / *Type*: list /
-  
+
   Trace file list if using dlt connection.
 
-* ``test_connection``    
+* ``test_connection``
 
   / *Condition*: optional / *Type*: bool /
-  
+
   Deternmine if it's necessary for testing the connection.
 
 **Returns:**
@@ -235,16 +233,16 @@ Abstract method for quiting the connection.
    @abc.abstractmethod
    def disconnect(self, device):
       """
->> This method MUST be overridden in derived class << 
+>> This method MUST be overridden in derived class <<
 
 Abstract method for disconnecting connection.
-      
-**Arguments:**   
+
+**Arguments:**
 
 * ``device``
 
   / *Condition*: required / *Type*: str /
-  
+
   Device's name.
 
 **Returns:**
@@ -258,11 +256,14 @@ Abstract method for disconnecting connection.
    def _init_thrd_llrecv(self, n_thrd_id):
       """
 Start a thread which receive message from connection continuously.
-      
-**Arguments:**   
 
+**Arguments:**
 
-         n_thrd_id: thread id.
+* ``n_thrd_id``
+
+  / *Condition*: required / *Type*: int /
+
+  Thread ID number.
 
 **Returns:**
 
@@ -279,7 +280,7 @@ Start a thread which receive message from connection continuously.
       """
 >> This method will be override in derived class << \
 The thread which receive message from connection continuously.
-	  
+
 **Returns:**
 
 (*no returns*)
@@ -289,25 +290,25 @@ The thread which receive message from connection continuously.
    def _init_thread_receiver(self, thread_id, mode=None, sync_with_start=False):
       """
 Initialize a thread for receiving data from connection.
-      
+
 **Arguments:**
 
-* ``thread_id``    
+* ``thread_id``
 
   / *Condition*: required / *Type*: int /
-  
+
   Thread ID number.
 
-* ``mode``    
+* ``mode``
 
   / *Condition*: optional / *Type*: str /
-  
+
   Connection's mode.
 
-* ``sync_with_start``    
+* ``sync_with_start``
 
   / *Condition*: optional / *Type*: bool /
-  
+
   Determine if receiving thread needs to wait for start event.
 
 **Returns:**
@@ -318,27 +319,37 @@ Initialize a thread for receiving data from connection.
       thread_name = self._CONNECTION_TYPE
       if mode is not None:
          thread_name = mode
-      conn_id_name = str(thread_name) + str(thread_id)
+
+      if hasattr(self, 'connection_name'):
+         thread_name = self.connection_name
+
+
+      conn_id_name = str(thread_name) + '-' + str(thread_id)
       self._logger = QLogger().get_logger(conn_id_name)
       self._logger_handler = QLogger().set_handler(self.config)
+
+      self._traceq_obj = {}
+      self._traceq_lock = threading.Lock()
+
+
       self._recv_thrd_term = threading.Event()
       self._recv_thrd_obj = threading.Thread(target=self._thread_receive_from_connection, kwargs=dict(sync_with_start=sync_with_start))
       self._recv_thrd_obj.setDaemon(True)
 
       self._recv_thrd_obj.name = conn_id_name
-      BuiltIn().log("%s: starting receiver thread '%s'" % (_mident, self._recv_thrd_obj.name))
+      BuiltIn().log("%s: starting receiver thread '%s'" % (_mident, self._recv_thrd_obj.name), constants.LOG_LEVEL_DEBUG)
       self._recv_thrd_obj.start()
 
    def _thread_receive_from_connection(self, sync_with_start=False):
       """
 Thread to receive data from connection continuously.
-      
-**Arguments:**   
 
-* ``sync_with_start``    
+**Arguments:**
+
+* ``sync_with_start``
 
   / *Condition*: optional / *Type*: bool /
-  
+
   Determine if receiving thread needs to wait for start event.
 
 **Returns:**
@@ -369,21 +380,28 @@ Thread to receive data from connection continuously.
                #    for q in self._msgq_c_obj.values():
                #       q.put((now, msg), False)
 
-               with self.__class__._traceq_lock:
-                  if self.__class__._traceq_obj:
-                     for (regex_filter, msg_queue, back_trace_queue, use_fetch_block, regex_end_block_pattern, regex_line_filter) in self.__class__._traceq_obj.values():
+               with self._traceq_lock:
+                  if self._traceq_obj:
+                     for (regex_filter, msg_queue, back_trace_queue, use_fetch_block, regex_end_block_pattern, regex_line_filter) in self._traceq_obj.values():
                         is_hit = False
                         result_obj = None
                         if use_fetch_block is True:
                            matchObj = regex_line_filter.search(msg)
                            if matchObj is not None:
                               back_trace_queue.append(msg)
-                              (is_hit, result_obj) = self._filter_msg(regex_end_block_pattern, msg)
+                              # BuiltIn().log_to_console(msg)
+                              if regex_end_block_pattern and regex_end_block_pattern.pattern != ".*":
+                                (is_hit, result_obj) = self._filter_msg(regex_end_block_pattern, msg)
+                              else:
+                                # BuiltIn().log_to_console(regex_filter.pattern)
+                                # BuiltIn().log_to_console(msg)
+                                # BuiltIn().log_to_console("\r\n".join(back_trace_queue))
+                                (is_hit, result_obj) = self._filter_msg(regex_filter, "\n".join(back_trace_queue))
                         else:
                            (is_hit, result_obj) = self._filter_msg(regex_filter, msg)
                         if is_hit:
                            now = time.time()
-                           if use_fetch_block is True:
+                           if use_fetch_block is True and regex_end_block_pattern.pattern != ".*":
                               result_obj = regex_filter.search("\r\n".join(back_trace_queue))
                               back_trace_queue.clear()
                            msg_queue.put((now, result_obj), False)
@@ -400,22 +418,22 @@ Thread to receive data from connection continuously.
       BuiltIn().log("%s: receiver thread terminated." % _mident, constants.LOG_LEVEL_DEBUG)
 
 
-   def send_obj(self, send_cmd, cr=True):
+   def send_obj(self, send_cmd, cr=True, **kwargs):
       """
 Wrapper method to send message to a tcp connection.
-      
+
 **Arguments:**
 
-* ``obj``    
+* ``send_cmd``
 
   / *Condition*: required / *Type*: str /
-  
+
   Data to be sent.
-  
-* ``cr``    
+
+* ``cr``
 
   / *Condition*: optional / *Type*: str /
-  
+
   Determine if it's necessary to add newline character at the end of command.
 
 **Returns:**
@@ -430,19 +448,20 @@ Wrapper method to send message to a tcp connection.
          try:
             BuiltIn().log("%s: sending: '%s'" % (_mident, msg), constants.LOG_LEVEL_DEBUG)
             self._send(msg, cr)
-         except:
+         except Exception as ex:
             self._is_connected = False
+            raise BrokenConnError(f"Connection has been broken. Details: {ex}")
 
    def read_obj(self):
       """
 Wrapper method to get the response from connection.
-	  
+
 **Returns:**
 
 * ``msg``
 
   / *Type*: str /
-  
+
   Responded message.
       """
       _mident = '%s.%s()' % (self.__class__.__name__, currentframe().f_code.co_name)
@@ -458,7 +477,7 @@ Wrapper method to get the response from connection.
             self._is_connected = False
             raise reason
          except Exception as reason:
-            BuiltIn().log("%s: %s" % (_mident, reason), constants.LOG_LEVEL_WARNING)
+            BuiltIn().log("%s: %s" % (_mident, reason), constants.LOG_LEVEL_DEBUG)
       return msg
    # endregion
 
@@ -466,44 +485,44 @@ Wrapper method to get the response from connection.
    def wait_4_trace(self, search_obj, timeout=0, use_fetch_block=False, end_of_block_pattern=".*", filter_pattern=".*", **fct_args):
       """
 Suspend the control flow until a Trace message is received which matches to a specified regular expression.
-      
-**Arguments:**   
 
-* ``search_obj``    
+**Arguments:**
+
+* ``search_obj``
 
   / *Condition*: required / *Type*: str /
-  
-  Regular expression all received trace messages are compare to. 
-  Can be passed either as a string or a regular expression object. Refer to Python documentation for module 're'.
-  
-* ``use_fetch_block``    
+
+  Regular expression all received trace messages are compare to.
+  Can be passed either as a string or a regular expression object. Refer to Python documentation for module '``re``'.
+
+* ``use_fetch_block``
 
   / *Condition*: optional / *Type*: bool / *Default*: False /
-  
-  Determine if 'fetch block' feature is used.
-  
-* ``end_of_block_pattern``    
+
+  Determine if '``fetch block``' feature is used.
+
+* ``end_of_block_pattern``
 
   / *Condition*: optional / *Type*: str / *Default*: '.*' /
-  
-  The end of block pattern.  
 
-* ``filter_pattern``    
+  The end of block pattern.
+
+* ``filter_pattern``
 
   / *Condition*: optional / *Type*: str / *Default*: '.*' /
-  
+
   Pattern to filter message line by line.
-  
-* ``timeout``    
+
+* ``timeout``
 
   / *Condition*: optional / *Type*: int / *Default*: 0 /
-  
+
   Timeout parameter specified as a floating point number in the unit 'seconds'.
-  
-* ``fct_args``    
+
+* ``fct_args``
 
   / *Condition*: optional / *Type*: Tuple /  *Default*: None /
-  
+
   List of function arguments passed to be sent.
 
 **Returns:**
@@ -511,19 +530,25 @@ Suspend the control flow until a Trace message is received which matches to a sp
 * ``match``
 
   / *Type*: re.Match /
-  
-  If no trace message matched to the specified regular expression and a timeout occurred, return None.
-  
-  If a trace message has matched to the specified regular expression, a match object is returned as the result.The complete trace message can be accessed by the 'string' attribute of the match object. For access to groups within the regular expression, use the group() method. For more information, refer to Python documentation for module 're'.
+
+  If no trace message matched to the specified regular expression and a timeout occurred, return ``None``.
+
+  If a trace message has matched to the specified regular expression, a match object is returned as the result.The complete trace message can be accessed by the '``string``' attribute of the match object. For access to groups within the regular expression, use the ``group()`` method. For more information, refer to Python documentation for module '``re``'.
       """
+      if self._broken_conn.is_set():
+         raise Exception(constants.String.CONNECTION_BROKEN)
       _mident = '%s.%s()' % (self.__class__.__name__, currentframe().f_code.co_name)
       BuiltIn().log('Execute %s' % _mident, constants.LOG_LEVEL_DEBUG)
+      if search_obj is None:
+         raise Exception("The 'search_pattern' have to be a regex string instead of None.")
       search_regex = re.compile(search_obj, re.M | re.S | re.U)
       regex_obj_filter = re.compile(filter_pattern)
       trq_handle, trace_queue = self.create_and_activate_trace_queue(search_regex, use_fetch_block, end_of_block_pattern, regex_obj_filter)
 
       try:
          self.send_obj(**fct_args)
+      except BrokenConnError:
+         raise Exception(constants.String.CONNECTION_BROKEN)
       except Exception as err_msg:  # pylint: disable=W0703
          BuiltIn().log('%s: An Exception occurred executing function object: %s' % (_mident, repr(self.send_obj)), 'ERROR')
          BuiltIn().log('Function Arguments: %s' % repr(fct_args), 'ERROR')
@@ -543,30 +568,29 @@ Suspend the control flow until a Trace message is received which matches to a sp
       else:
          return None
 
-
    def wait_4_trace_continuously(self, trace_queue, timeout=0, *fct_args):
       """
 Getting trace log continuously without creating a new trace queue.
-      
-**Arguments:**   
+
+**Arguments:**
 
 
-* ``trace_queue``    
+* ``trace_queue``
 
   / *Condition*: required / *Type*: Queue /
-  
+
   Queue to store the traces.
-  
-* ``timeout``    
+
+* ``timeout``
 
   / *Condition*: optional / *Type*: int / *Default*: 0 /
-  
+
   Timeout for waiting a matched log.
 
-* ``fct_args``    
+* ``fct_args``
 
   / *Condition*: optional / *Type*: Tuple / *Default*: None /
-  
+
   Arguments to be sent to connection.
 
 **Returns:**
@@ -574,14 +598,14 @@ Getting trace log continuously without creating a new trace queue.
 * ``None``
 
   / *Type*: None /
-  
+
   If no trace message matched to the specified regular expression and a timeout occurred.
-  
+
 * ``match``
 
   / *Type*: re.Match /
-  
-  If a trace message has matched to the specified regular expression, a match object is returned as the result.The complete trace message can be accessed by the 'string' attribute of the match object. For access to groups within the regular expression, use the group() method. For more information, refer to Python documentation for module 're'.
+
+  If a trace message has matched to the specified regular expression, a match object is returned as the result.The complete trace message can be accessed by the '``string``' attribute of the match object. For access to groups within the regular expression, use the ``group()`` method. For more information, refer to Python documentation for module '``re``'.
       """
       _mident = '%s.%s()' % (self.__class__.__name__, currentframe().f_code.co_name)
       BuiltIn().log('Execute %s' % _mident, constants.LOG_LEVEL_DEBUG)
@@ -606,37 +630,37 @@ Getting trace log continuously without creating a new trace queue.
       else:
          return None
 
-   @classmethod
-   def create_and_activate_trace_queue(cls, search_element, use_fetch_block=False, end_of_block_pattern='.*', regex_line_filter_pattern=None):
+   # @classmethod
+   def create_and_activate_trace_queue(self, search_element, use_fetch_block=False, end_of_block_pattern='.*', regex_line_filter_pattern=None):
       """
 Create Queue and assign it to _trace_queue object and activate the queue with the search element.
-      
-**Arguments:**   
 
-* ``search_element``    
+**Arguments:**
+
+* ``search_element``
 
   / *Condition*: required / *Type*: str /
-  
-  Regular expression all received trace messages are compare to. 
-         
-  Can be passed either as a string or a regular expression object. Refer to Python documentation for module 're'.#
 
-* ``use_fetch_block``    
+  Regular expression all received trace messages are compare to.
+
+  Can be passed either as a string or a regular expression object. Refer to Python documentation for module '``re``'.
+
+* ``use_fetch_block``
 
   / *Condition*: optional / *Type*: bool / *Default*: False /
-  
+
   Determine if 'fetch block' feature is used.
-  
-* ``end_of_block_pattern``    
+
+* ``end_of_block_pattern``
 
   / *Condition*: optional / *Type*: str / *Default*: '.*' /
-  
+
   The end of block pattern.
-  
-* ``regex_line_filter_pattern``    
+
+* ``regex_line_filter_pattern``
 
   / *Condition*: optional / *Type*: re.Pattern / *Default*: None /
-  
+
   Regular expression object to filter message line by line.
 
 **Returns:**
@@ -644,116 +668,116 @@ Create Queue and assign it to _trace_queue object and activate the queue with th
 * ``trq_handle, trace_queue``
 
   / *Type*: tuple /
-  
+
   The handle and search object
       """
       trace_queue = queue.Queue()
-      trq_handle = cls.activate_trace_queue(search_element, trace_queue, use_fetch_block, end_of_block_pattern, regex_line_filter_pattern)
+      trq_handle = self.activate_trace_queue(search_element, trace_queue, use_fetch_block, end_of_block_pattern, regex_line_filter_pattern)
       return trq_handle, trace_queue
 
-   @classmethod
-   def deactivate_and_delete_trace_queue(cls, trq_handle, trace_queue):
+   # @classmethod
+   def deactivate_and_delete_trace_queue(self, trq_handle, trace_queue):
       """
 Deactivate trace queue and delete.
-      
-**Arguments:**   
 
-* ``trq_handle``    
+**Arguments:**
+
+* ``trq_handle``
 
   / *Condition*: required / *Type*: int /
-  
+
   Trace queue handle.
-  
-* ``trace_queue``    
+
+* ``trace_queue``
 
   / *Condition*: required / *Type*: Queue /
-  
+
   Trace queue object.
 
 **Returns:**
 
 (*no returns*)
       """
-      cls.deactivate_trace_queue(trq_handle)
+      self.deactivate_trace_queue(trq_handle)
       del trace_queue
 
-   @classmethod
-   def activate_trace_queue(cls, search_obj, trace_queue, use_fetch_block=False, end_of_block_pattern='.*', line_filter_pattern=None):
+   # @classmethod
+   def activate_trace_queue(self, search_obj, trace_queue, use_fetch_block=False, end_of_block_pattern='.*', line_filter_pattern=None):
       """
 Activates a trace message filter specified as a regular expression. All matching trace messages are put in the specified queue object.
-      
-**Arguments:**   
 
-* ``search_obj``    
+**Arguments:**
+
+* ``search_obj``
 
   / *Condition*: required / *Type*: str /
-  
+
   Regular expression all received trace messages are compare to. \
-         
-  Can be passed either as a string or a regular expression object. Refer to Python documentation for module 're'.
-  
-* ``trace_queue``    
+
+  Can be passed either as a string or a regular expression object. Refer to Python documentation for module '``re``'.
+
+* ``trace_queue``
 
   / *Condition*: required / *Type*: Queue /
-  
+
   A queue object all trace message which matches the regular expression are put in. \
-  
+
   The using application must assure, that the queue is emptied or deleted.
-  
-* ``use_fetch_block``    
+
+* ``use_fetch_block``
 
   / *Condition*: optional / *Type*: bool /  *Default*: False /
-  
+
   Determine if 'fetch block' feature is used.
-  
-* ``end_of_block_pattern``    
+
+* ``end_of_block_pattern``
 
   / *Condition*: optional / *Type*: str / *Default*: '.*' /
-  
+
   The end of block pattern.
-  
-* ``line_filter_pattern``    
+
+* ``line_filter_pattern``
 
   / *Condition*: optional / *Type*: re.Pattern / *Default*: None /
-  
+
   Regular expression object to filter message line by line.
-          
+
 **Returns:**
 
 * ``handle_id``
 
   / *Type*: int /
-  
+
   Handle to deactivate the message filter.
       """
-      _mident = '%s.%s()' % (cls.__class__.__name__, currentframe().f_code.co_name)
+      _mident = '%s.%s()' % (self.__class__.__name__, currentframe().f_code.co_name)
       BuiltIn().log('Execute %s' % _mident, constants.LOG_LEVEL_DEBUG)
-      with cls._traceq_lock:
-         cls._traceq_handle += 1
-         back_trace_queue = deque(maxlen=cls.MAX_LEN_BACKTRACE)
+      with self._traceq_lock:
+         self.__class__._traceq_handle += 1
+         back_trace_queue = deque(maxlen=self.__class__.MAX_LEN_BACKTRACE)
          search_regex_obj = re.compile(search_obj)
-         cls._traceq_obj[cls._traceq_handle] = (search_regex_obj,
+         self._traceq_obj[self.__class__._traceq_handle] = (search_regex_obj,
                                                 trace_queue,
                                                 back_trace_queue,
                                                 use_fetch_block,
                                                 re.compile(end_of_block_pattern, re.M | re.S | re.U),
                                                 line_filter_pattern)
-         handle_id = cls._traceq_handle
+         handle_id = self.__class__._traceq_handle
       BuiltIn().log('Completed %s' % _mident, constants.LOG_LEVEL_DEBUG)
       return handle_id
 
-   @classmethod
-   def deactivate_trace_queue(cls, handle):
+   # @classmethod
+   def deactivate_trace_queue(self, handle):
       """
 Deactivates a trace message filter previously activated by ActivateTraceQ() method.
-      
+
 **Arguments:**
 
-* ``handle``    
+* ``handle``
 
   / *Condition*: required / *Type*: int /
-  
-  Integer object returned by ActivateTraceQ() method.
+
+  Integer object returned by ``ActivateTraceQ()`` method.
 
 **Returns:**
 
@@ -761,15 +785,15 @@ Deactivates a trace message filter previously activated by ActivateTraceQ() meth
 
   / *Type*: bool /
  .
-  False : No trace message filter active with the specified handle (i.e. handle is not in use). 
-  
-  True :  Trace message filter successfully deleted.
+  ``False`` : No trace message filter active with the specified handle (i.e. handle is not in use).
+
+  ``True`` :  Trace message filter successfully deleted.
       """
-      _mident = '%s.%s()' % (cls.__class__.__name__, currentframe().f_code.co_name)
+      _mident = '%s.%s()' % (self.__class__.__name__, currentframe().f_code.co_name)
       BuiltIn().log('Execute %s' % _mident, constants.LOG_LEVEL_DEBUG)
-      with cls._traceq_lock:
-         if handle in cls._traceq_obj:
-            del cls._traceq_obj[handle]
+      with self._traceq_lock:
+         if handle in self._traceq_obj:
+            del self._traceq_obj[handle]
             is_success = True
          else:
             is_success = False
@@ -778,16 +802,16 @@ Deactivates a trace message filter previously activated by ActivateTraceQ() meth
 
    def check_timeout(self, timeout):
       """
->> This method will be override in derived class << 
+>> This method will be override in derived class <<
 
 Check if responded message come in cls._RESPOND_TIMEOUT or we will raise a timeout event.
-      
-**Arguments:**   
 
-* ``timeout``    
+**Arguments:**
+
+* ``timeout``
 
   / *Condition*: required / *Type*: int /
-  
+
   Timeout in seconds.
 
 **Returns:**
@@ -801,13 +825,13 @@ Check if responded message come in cls._RESPOND_TIMEOUT or we will raise a timeo
 >> This method will be override in derived class <<
 
 Pre-checking message when receiving it from connection.
-      
-**Arguments:**   
 
-* ``msg``    
+**Arguments:**
+
+* ``msg``
 
   / *Condition*: required / *Type*: str /
-  
+
   Received message to be checked.
 
 **Returns:**
@@ -818,16 +842,16 @@ Pre-checking message when receiving it from connection.
 
    def post_msg_check(self, msg):
       """
->> This method will be override in derived class <<
+>> This method should be overridden in the derived class <<
 
 Post-checking message when receiving it from connection.
-      
-**Arguments:**   
 
-* ``msg``    
+**Arguments:**
+
+* ``msg``
 
   / *Condition*: required / *Type*: str /
-  
+
   Received message to be checked.
 
 **Returns:**
@@ -842,8 +866,8 @@ Post-checking message when receiving it from connection.
    def _rm_q_dollar(input_):
       # noinspection PyBroadException
       try:
-         output = input_.replace("\$(", "$(")
-         output = output.replace("\${", "${")
+         output = input_.replace(r"\$(", "$(")
+         output = output.replace(r"\${", "${")
       except:
          # in case of any issue return input as it is
          output = input_
@@ -854,8 +878,8 @@ Post-checking message when receiving it from connection.
    def _q_dollar(input_):
       # noinspection PyBroadException
       try:
-         output = input_.replace("$(", "\$(")
-         output = output.replace("${", "\${")
+         output = input_.replace("$(", r"\$(")
+         output = output.replace("${", r"\${")
       except:
          # in case of any issue return input as it is
          output = input_
@@ -865,19 +889,19 @@ Post-checking message when receiving it from connection.
    def _filter_msg(self, regex_filter_obj, msg):
       """
 Filter message by regular expression object.
-      
-**Arguments:**   
 
-* ``regex_filter_obj``    
+**Arguments:**
+
+* ``regex_filter_obj``
 
   / *Condition*: required / *Type*: re.Pattern /
-  
+
   Regular expression object.
-  
-* ``msg``    
+
+* ``msg``
 
   / *Condition*: required / *Type*: str /
-  
+
   Message string to be filtered.
 
 **Returns:**
@@ -885,10 +909,10 @@ Filter message by regular expression object.
 * ``is_hit, matched_obj``
 
   / *Type*: tuple /
-  
-  is_hit: Determine if there is any matched.
-		 
-  matched_obj: Matched object if exists.
+
+  ``is_hit``: Determine if there is any matched.
+
+  ``matched_obj``: Matched object if exists.
       """
       _mident = '%s.%s()' % (self.__class__.__name__, currentframe().f_code.co_name)
       BuiltIn().log(_mident, constants.LOG_LEVEL_DEBUG)
