@@ -121,10 +121,15 @@ Constructor for ConnectionManager class.
       site_package_dirs = site.getsitepackages()
       extension_lib_paths = []
       for site_package_dir in site_package_dirs:
-         curr_dir = os.walk(site_package_dir).__next__()[0]
-         lib_path = [constants.SLASH.join([curr_dir, lib_ext]) for lib_ext in os.walk(site_package_dir).__next__()[1]
-                     if (ConnectionManager.LIBRARY_EXTENSION_PREFIX in lib_ext) or lib_ext.startswith(ConnectionManager.LIBRARY_EXTENSION_PREFIX2)]
-         extension_lib_paths.extend(lib_path)
+         try:
+            walk_iter = os.walk(site_package_dir)
+            curr_dir, subdirs, files = next(walk_iter)
+            lib_path = [constants.SLASH.join([curr_dir, lib_ext]) for lib_ext in subdirs
+                        if (ConnectionManager.LIBRARY_EXTENSION_PREFIX in lib_ext) or lib_ext.startswith(ConnectionManager.LIBRARY_EXTENSION_PREFIX2)]
+            extension_lib_paths.extend(lib_path)
+         except (StopIteration, OSError):
+            # Skip if site package directory doesn't exist or is inaccessible
+            continue
 
       all_libs = [main_lib_path]
       all_libs.extend(extension_lib_paths)
@@ -355,8 +360,8 @@ Making a connection.
       conn_conf['connection_name'] = conn_name
 
       if conn_type not in self.supported_connection_classes_dict.keys():
-         raise Exception("The connection type '%s' is not supported. Please choose one of: %s." %
-                              (conn_type, ', '.join(sorted(k for k in self.supported_connection_classes_dict.keys() if not k.endswith('Base')))))
+         raise Exception(constants.String.CONNECTION_TYPE_UNSUPPORTED %
+                         (conn_type, ', '.join(sorted(k for k in self.supported_connection_classes_dict.keys() if not k.endswith('Base')))))
 
       if 'conn_mode' in conn_conf:
          if conn_conf['conn_mode'] != conn_mode and conn_mode != '':
@@ -723,6 +728,20 @@ Verify a pattern from connection response after sending a command.
   i.e. the second *captured string* defined in the pattern ``(command)``.
 
       """
+      # Parameter validation: eob_pattern and filter_pattern are only valid when fetch_block is True
+      if not fetch_block:
+         if eob_pattern != '.*':
+            raise Exception("Parameter 'eob_pattern' is only applicable when 'fetch_block' is True. "
+                           f"Current values: fetch_block={fetch_block}, eob_pattern='{eob_pattern}'")
+         if filter_pattern != '.*':
+            raise Exception("Parameter 'filter_pattern' is only applicable when 'fetch_block' is True. "
+                           f"Current values: fetch_block={fetch_block}, filter_pattern='{filter_pattern}'")
+      else:
+         if eob_pattern and has_capturing_groups(eob_pattern):
+            BuiltIn().log(f"Warning: eob_pattern '{eob_pattern}' contains capturing groups, which may not work as expected for end-of-block detection.", constants.LOG_LEVEL_WARNING)
+         if filter_pattern and has_capturing_groups(filter_pattern):
+            BuiltIn().log(f"Warning: filter_pattern '{filter_pattern}' contains capturing groups, which may not work as expected for filtering message.", constants.LOG_LEVEL_WARNING)
+
       if conn_name not in self.connection_manage_dict.keys():
          raise AssertionError("The '%s' connection hasn't been established. Please connect first." % conn_name)
 
@@ -747,27 +766,29 @@ Verify a pattern from connection response after sending a command.
          kwargs['send_cmd'] = send_cmd
          res = connection_obj.wait_4_trace(search_pattern, int(timeout), fetch_block, eob_pattern, filter_pattern, **kwargs)
          if res is None:
-            # raise AssertionError("Unable to match the pattern after '%s' seconds." % timeout)
-            # 14.02.2025 qth2hi changed
-            # original # BuiltIn().log("Match try %s/%s timed out" % (i, match_try), constants.LOG_LEVEL_WARNING)
             log_level = constants.LOG_LEVEL_WARNING if (i == match_try) else constants.LOG_LEVEL_INFO
             BuiltIn().log(f"[{conn_name}] Match try {i}/{match_try} timed out ('{search_pattern}')", log_level)
          else:
             break
 
       if not res:
-         # 14.02.2025 qth2hi changed
-         # raise AssertionError(f"Unable to match the pattern after '{match_try}' {'try' if match_try == 1 else 'tries'}.")
-         raise AssertionError(f"Unable to match the pattern '{search_pattern}' after '{match_try}' {'try' if match_try == 1 else 'tries'} ({conn_name}).")
+         raise AssertionError(f"Failed to match the pattern '{search_pattern}' within '{match_try}' {'try' if match_try == 1 else 'tries'} ({conn_name}).")
+
+      # Determine if the pattern has capturing groups
+      has_groups = has_capturing_groups(search_pattern) if search_pattern else False
 
       if hasattr(res, "groups"):
-         match_res = [str(g) for g in res.groups()]
+         if has_groups:
+            match_res = [str(g) for g in res.groups()]
+         else:
+            match_res = None
       elif isinstance(res, dict):
          match_res = res
       else:
          match_res = [str(res)]
 
-      BuiltIn().log(f"Received expected response '{match_res}' from '{conn_name}'", constants.LOG_LEVEL_INFO)
+      BuiltIn().log(f"Search pattern '{search_pattern}' matched (try {i}) on connection '{conn_name}'", constants.LOG_LEVEL_INFO)
+
       return match_res
 
 
